@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -23,17 +23,16 @@ the GenericBackend class
 """
 
 import os
-import sys
 import errno
 import pickle
 import threading
 from collections import deque
 
 from GTG.backends.backendsignals import BackendSignals
-from GTG.tools.keyring           import Keyring
-from GTG.core                    import CoreConfig
-from GTG.tools.logger            import Log
-from GTG.tools.interruptible     import _cancellation_point
+from GTG.tools.keyring import Keyring
+from GTG.core import CoreConfig
+from GTG.tools.logger import Log
+from GTG.tools.interruptible import _cancellation_point
 
 PICKLE_BACKUP_NBR = 2
 
@@ -46,17 +45,15 @@ class GenericBackend(object):
     A particular backend should redefine all the methods marked as such.
     '''
 
-
    ###########################################################################
    ### BACKEND INTERFACE #####################################################
    ###########################################################################
-
-    #General description of the backend: these parameters are used
-    #to show a description of the backend to the user when s/he is
-    #considering adding it.
+    # General description of the backend: these parameters are used
+    # to show a description of the backend to the user when s/he is
+    # considering adding it.
     # For an example, see the GTG/backends/backend_localfile.py file
-    #_general_description has this format:
-    #_general_description = {
+    # _general_description has this format:
+    # _general_description = {
     #    GenericBackend.BACKEND_NAME:       "backend_unique_identifier", \
     #    GenericBackend.BACKEND_HUMAN_NAME: _("Human friendly name"), \
     #    GenericBackend.BACKEND_AUTHORS:    ["First author", \
@@ -68,11 +65,11 @@ class GenericBackend(object):
     # The complete list of constants and their meaning is given below.
     _general_description = {}
 
-    #These are the parameters to configure a new backend of this type. A
+    # These are the parameters to configure a new backend of this type. A
     # parameter has a name, a type and a default value.
     # For an example, see the GTG/backends/backend_localfile.py file
-    #_static_parameters has this format:
-    #_static_parameters = { \
+    # _static_parameters has this format:
+    # _static_parameters = { \
     #    "param1_name": { \
     #        GenericBackend.PARAM_TYPE: GenericBackend.TYPE_STRING,
     #        GenericBackend.PARAM_DEFAULT_VALUE: "my default value",
@@ -88,13 +85,13 @@ class GenericBackend(object):
         '''
         Called each time it is enabled (including on backend creation).
         Please note that a class instance for each disabled backend *is*
-        created, but it's not initialized. 
-        Optional. 
+        created, but it's not initialized.
+        Optional.
         NOTE: make sure to call super().initialize()
         '''
         self._parameters[self.KEY_ENABLED] = True
         self._is_initialized = True
-        #we signal that the backend has been enabled
+        # we signal that the backend has been enabled
         self._signal_manager.backend_state_changed(self.get_id())
 
     def start_get_tasks(self):
@@ -121,7 +118,7 @@ class GenericBackend(object):
     def remove_task(self, tid):
         ''' This function is called from GTG core whenever a task must be
         removed from the backend. Note that the task could be not present here.
-        
+
         @param tid: the id of the task to delete
         '''
         pass
@@ -133,15 +130,15 @@ class GenericBackend(object):
         This function is needed only in the default backend (XML localfile,
         currently).
         The xml parameter is an object containing GTG default tasks.
-        
+
         @param xml: an xml object containing the default tasks.
         '''
         pass
 
-    def quit(self, disable = False):
+    def quit(self, disable=False):
         '''
         Called when GTG quits or the user wants to disable the backend.
-        
+
         @param disable: If disable is True, the backend won't
                         be automatically loaded when GTG starts
         '''
@@ -149,10 +146,10 @@ class GenericBackend(object):
             self._is_initialized = False
             if disable:
                 self._parameters[self.KEY_ENABLED] = False
-                #we signal that we have been disabled
+                # we signal that we have been disabled
                 self._signal_manager.backend_state_changed(self.get_id())
                 self._signal_manager.backend_sync_ended(self.get_id())
-            syncing_thread = threading.Thread(target = self.sync).run()
+            threading.Thread(target=self.sync).run()
 
     def save_state(self):
         '''
@@ -169,89 +166,88 @@ class GenericBackend(object):
    ###########################################################################
    ### CONSTANTS #############################################################
    ###########################################################################
-    #BACKEND TYPE DESCRIPTION
+    # BACKEND TYPE DESCRIPTION
     # Each backend must have a "_general_description" attribute, which
     # is a dictionary that holds the values for the following keys.
-    BACKEND_NAME = "name" #the backend gtg internal name (doesn't change in
+    BACKEND_NAME = "name"  # the backend gtg internal name (doesn't change in
                           # translations, *must be unique*)
-    BACKEND_HUMAN_NAME = "human-friendly-name" #The name shown to the user
-    BACKEND_DESCRIPTION = "description" #A short description of the backend
-    BACKEND_AUTHORS = "authors" #a list of strings
+    BACKEND_HUMAN_NAME = "human-friendly-name"  # The name shown to the user
+    BACKEND_DESCRIPTION = "description"  # A short description of the backend
+    BACKEND_AUTHORS = "authors"  # a list of strings
     BACKEND_TYPE = "type"
-    #BACKEND_TYPE is one of:
+    # BACKEND_TYPE is one of:
     TYPE_READWRITE = "readwrite"
     TYPE_READONLY = "readonly"
     TYPE_IMPORT = "import"
     TYPE_EXPORT = "export"
 
-
     #"static_parameters" is a dictionary of dictionaries, each of which
     # are a description of a parameter needed to configure the backend and
     # is identified in the outer dictionary by a key which is the name of the
     # parameter.
     # For an example, see the GTG/backends/backend_localfile.py file
     # Each dictionary contains the keys:
-    PARAM_DEFAULT_VALUE = "default_value" # its default value
-    PARAM_TYPE = "type"  
-    #PARAM_TYPE is one of the following (changing this changes the way
+    PARAM_DEFAULT_VALUE = "default_value"  # its default value
+    PARAM_TYPE = "type"
+    # PARAM_TYPE is one of the following (changing this changes the way
     # the user can configure the parameter)
-    TYPE_PASSWORD = "password" #the real password is stored in the GNOME
+    TYPE_PASSWORD = "password"  # the real password is stored in the GNOME
                                # keyring
                                # This is just a key to find it there
-    TYPE_STRING = "string"  #generic string, nothing fancy is done
-    TYPE_INT = "int"  #edit box can contain only integers
-    TYPE_BOOL = "bool" #checkbox is shown
-    TYPE_LIST_OF_STRINGS = "liststring" #list of strings. the "," character is
-                                        # prohibited in strings
+    TYPE_STRING = "string"  # generic string, nothing fancy is done
+    TYPE_INT = "int"  # edit box can contain only integers
+    TYPE_BOOL = "bool"  # checkbox is shown
+    TYPE_LIST_OF_STRINGS = "liststring"  # list of strings. the "," character
+                                         # is prohibited in strings
 
-    #These parameters are common to all backends and necessary.
+    # These parameters are common to all backends and necessary.
     # They will be added automatically to your _static_parameters list
-    #NOTE: for now I'm disabling changing the default backend. Once it's all
+    # NOTE: for now I'm disabling changing the default backend. Once it's all
     #      set up, we will see about that (invernizzi)
     KEY_DEFAULT_BACKEND = "Default"
-    KEY_ENABLED = "Enabled"
+    KEY_ENABLED = "enabled"
     KEY_HUMAN_NAME = BACKEND_HUMAN_NAME
     KEY_ATTACHED_TAGS = "attached-tags"
     KEY_USER = "user"
     KEY_PID = "pid"
-    ALLTASKS_TAG = "gtg-tags-all" #NOTE: this has been moved here to avoid
+    ALLTASKS_TAG = "gtg-tags-all"  # NOTE: this has been moved here to avoid
                                   #    circular imports. It's the same as in
                                   #    the CoreConfig class, because it's the
                                   #    same thing conceptually. It doesn't
                                   #    matter it the naming diverges.
 
-    _static_parameters_obligatory = { \
-                                    KEY_DEFAULT_BACKEND: { \
-                                         PARAM_TYPE: TYPE_BOOL, \
-                                         PARAM_DEFAULT_VALUE: False, \
-                                    }, \
-                                    KEY_HUMAN_NAME: { \
-                                         PARAM_TYPE: TYPE_STRING, \
-                                         PARAM_DEFAULT_VALUE: "", \
-                                    }, \
-                                    KEY_USER: { \
-                                         PARAM_TYPE: TYPE_STRING, \
-                                         PARAM_DEFAULT_VALUE: "", \
-                                    }, \
-                                    KEY_PID: { \
-                                         PARAM_TYPE: TYPE_STRING, \
-                                         PARAM_DEFAULT_VALUE: "", \
-                                    }, \
-                                    KEY_ENABLED: { \
-                                         PARAM_TYPE: TYPE_BOOL, \
-                                         PARAM_DEFAULT_VALUE: False, \
-                                    }}
+    _static_parameters_obligatory = {
+        KEY_DEFAULT_BACKEND: {
+            PARAM_TYPE: TYPE_BOOL,
+            PARAM_DEFAULT_VALUE: False,
+        },
+        KEY_HUMAN_NAME: {
+            PARAM_TYPE: TYPE_STRING,
+            PARAM_DEFAULT_VALUE: "",
+        },
+        KEY_USER: {
+            PARAM_TYPE: TYPE_STRING,
+            PARAM_DEFAULT_VALUE: "",
+        },
+        KEY_PID: {
+            PARAM_TYPE: TYPE_STRING,
+            PARAM_DEFAULT_VALUE: "",
+        },
+        KEY_ENABLED: {
+            PARAM_TYPE: TYPE_BOOL,
+            PARAM_DEFAULT_VALUE: False,
+        }}
 
-    _static_parameters_obligatory_for_rw = { \
-                                    KEY_ATTACHED_TAGS: {\
-                                         PARAM_TYPE: TYPE_LIST_OF_STRINGS, \
-                                         PARAM_DEFAULT_VALUE: [ALLTASKS_TAG], \
-                                    }}
-    
-    #Handy dictionary used in type conversion (from string to type)
+    _static_parameters_obligatory_for_rw = {
+        KEY_ATTACHED_TAGS: {
+            PARAM_TYPE: TYPE_LIST_OF_STRINGS,
+            PARAM_DEFAULT_VALUE: [ALLTASKS_TAG],
+        }}
+
+    # Handy dictionary used in type conversion (from string to type)
     _type_converter = {TYPE_STRING: str,
                        TYPE_INT: int,
-                      }
+                       }
 
     @classmethod
     def _get_static_parameters(cls):
@@ -263,13 +259,13 @@ class GenericBackend(object):
         '''
         temp_dic = cls._static_parameters_obligatory.copy()
         if cls._general_description[cls.BACKEND_TYPE] == \
-                                                        cls.TYPE_READWRITE:
+                cls.TYPE_READWRITE:
             for key, value in \
-                      cls._static_parameters_obligatory_for_rw.iteritems():
+                    cls._static_parameters_obligatory_for_rw.iteritems():
                 temp_dic[key] = value
         for key, value in cls._static_parameters.iteritems():
             temp_dic[key] = value
-        return temp_dic 
+        return temp_dic
 
     def __init__(self, parameters):
         """
@@ -278,29 +274,29 @@ class GenericBackend(object):
         want to check out the initialize() function.
         """
         if self.KEY_DEFAULT_BACKEND not in parameters:
-            #if it's not specified, then this is the default backend
+            # if it's not specified, then this is the default backend
             #(for retro-compatibility with the GTG 0.2 series)
             parameters[self.KEY_DEFAULT_BACKEND] = True
-        #default backends should get all the tasks
+        # default backends should get all the tasks
         if parameters[self.KEY_DEFAULT_BACKEND] or \
-                (not self.KEY_ATTACHED_TAGS in parameters and \
-                self._general_description[self.BACKEND_TYPE] \
-                                        == self.TYPE_READWRITE):
+                (not self.KEY_ATTACHED_TAGS in parameters and
+                 self._general_description[self.BACKEND_TYPE]
+                 == self.TYPE_READWRITE):
             parameters[self.KEY_ATTACHED_TAGS] = [self.ALLTASKS_TAG]
         self._parameters = parameters
         self._signal_manager = BackendSignals()
         self._is_initialized = False
-        #if debugging mode is enabled, tasks should be saved as soon as they're
-        # marked as modified. If in normal mode, we prefer speed over easier
-        # debugging.
+        # if debugging mode is enabled, tasks should be saved as soon as
+        # they're marked as modified. If in normal mode, we prefer speed over
+        # easier debugging.
         if Log.is_debugging_mode():
             self.timer_timestep = 5
         else:
-            self.timer_timestep = 1 
+            self.timer_timestep = 1
         self.to_set_timer = None
         self.please_quit = False
-        self.cancellation_point = lambda: _cancellation_point(\
-                                        lambda: self.please_quit)
+        self.cancellation_point = lambda: _cancellation_point(
+            lambda: self.please_quit)
         self.to_set = deque()
         self.to_remove = deque()
 
@@ -309,10 +305,10 @@ class GenericBackend(object):
         Returns the list of tags which are handled by this backend
         '''
         if hasattr(self._parameters, self.KEY_DEFAULT_BACKEND) and \
-                   self._parameters[self.KEY_DEFAULT_BACKEND]:
-            #default backends should get all the tasks
-            #NOTE: this shouldn't be needed, but it doesn't cost anything and it
-            #      could avoid potential tasks losses.
+                self._parameters[self.KEY_DEFAULT_BACKEND]:
+            # default backends should get all the tasks
+            # NOTE: this shouldn't be needed, but it doesn't cost anything and
+            #      it could avoid potential tasks losses.
             return [self.ALLTASKS_TAG]
         try:
             return self._parameters[self.KEY_ATTACHED_TAGS]
@@ -402,7 +398,7 @@ class GenericBackend(object):
                 return False
             else:
                 raise Exception("Unrecognized bool value '%s'" %
-                                 param_type)
+                                param_type)
         elif param_type == cls.TYPE_PASSWORD:
             if param_value == -1:
                 return None
@@ -425,7 +421,7 @@ class GenericBackend(object):
         @returns something: param_value casted to string
         '''
         if param_type == GenericBackend.TYPE_PASSWORD:
-            if param_value == None:
+            if param_value is None:
                 return str(-1)
             else:
                 return str(Keyring().set_password(
@@ -463,7 +459,7 @@ class GenericBackend(object):
         @returns string: the "human name" of this backend
         '''
         if self.KEY_HUMAN_NAME in self._parameters and \
-                    self._parameters[self.KEY_HUMAN_NAME] != "":
+                self._parameters[self.KEY_HUMAN_NAME] != "":
             return self._parameters[self.KEY_HUMAN_NAME]
         else:
             return self.get_human_default_name()
@@ -475,7 +471,7 @@ class GenericBackend(object):
         @param name: the new name
         '''
         self._parameters[self.KEY_HUMAN_NAME] = name
-        #we signal the change
+        # we signal the change
         self._signal_manager.backend_renamed(self.get_id())
 
     def is_enabled(self):
@@ -485,7 +481,7 @@ class GenericBackend(object):
         @returns: bool
         '''
         return self.get_parameters()[GenericBackend.KEY_ENABLED] or \
-                self.is_default()
+            self.is_default()
 
     def is_default(self):
         '''
@@ -505,9 +501,9 @@ class GenericBackend(object):
 
     def get_parameter_type(self, param_name):
         '''
-        Given the name of a parameter, returns its type. If the parameter is one
-        of the default ones, it does not have a type: in that case, it returns
-        None
+        Given the name of a parameter, returns its type. If the parameter is
+         one of the default ones, it does not have a type: in that case, it
+        returns None
 
         @param param_name: the name of the parameter
         @returns string: the type, or None
@@ -519,8 +515,8 @@ class GenericBackend(object):
 
     def register_datastore(self, datastore):
         '''
-        Setter function to inform the backend about the datastore that's loading
-        it.
+        Setter function to inform the backend about the datastore that's
+        loading it.
 
         @param datastore: a Datastore
         '''
@@ -529,7 +525,6 @@ class GenericBackend(object):
 ###############################################################################
 ### HELPER FUNCTIONS ##########################################################
 ###############################################################################
-
     def _store_pickled_file(self, path, data):
         '''
         A helper function to save some object in a file.
@@ -539,17 +534,17 @@ class GenericBackend(object):
         @param data: the object
         '''
         path = os.path.join(CoreConfig().get_data_dir(), path)
-        #mkdir -p
+        # mkdir -p
         try:
             os.makedirs(os.path.dirname(path))
         except OSError, exception:
-            if exception.errno != errno.EEXIST: 
+            if exception.errno != errno.EEXIST:
                 raise
 
         # Shift backups
         for i in range(PICKLE_BACKUP_NBR, 1, -1):
             destination = "%s.bak.%d" % (path, i)
-            source = "%s.bak.%d" % (path, i-1)
+            source = "%s.bak.%d" % (path, i - 1)
 
             if os.path.exists(destination):
                 os.unlink(destination)
@@ -563,11 +558,11 @@ class GenericBackend(object):
             if os.path.exists(path):
                 os.rename(path, destination)
 
-        #saving
+        # saving
         with open(path, 'wb') as file:
                 pickle.dump(data, file)
 
-    def _load_pickled_file(self, path, default_value = None):
+    def _load_pickled_file(self, path, default_value=None):
         '''
         A helper function to load some object from a file.
 
@@ -584,29 +579,28 @@ class GenericBackend(object):
             try:
                 return pickle.load(file)
             except Exception:
-                Log.error("Pickle file for backend '%s' is damaged" % \
-                    self.get_name())
+                Log.error("Pickle file for backend '%s' is damaged" %
+                          self.get_name())
 
         # Loading file failed, trying backups
-        for i in range(1, PICKLE_BACKUP_NBR+1):
+        for i in range(1, PICKLE_BACKUP_NBR + 1):
             backup_file = "%s.bak.%d" % (path, i)
             if os.path.exists(backup_file):
                 with open(backup_file, 'r') as file:
                     try:
                         data = pickle.load(file)
-                        Log.info("Succesfully restored backup #%d for '%s'" % \
-                            (i, self.get_name()))
+                        Log.info("Succesfully restored backup #%d for '%s'" %
+                                (i, self.get_name()))
                         return data
                     except Exception:
-                        Log.error("Backup #%d for '%s' is damaged as well" % \
-                            (i, self.get_name()))
+                        Log.error("Backup #%d for '%s' is damaged as well" %
+                                 (i, self.get_name()))
 
         # Data could not be loaded, degrade to default data
-        Log.error("There is no suitable backup for '%s', " \
-            "loading default data" % self.get_name())
+        Log.error("There is no suitable backup for '%s', "
+                  "loading default data" % self.get_name())
         return default_value
 
-
     def _gtg_task_is_syncable_per_attached_tags(self, task):
         '''
         Helper function which checks if the given task satisfies the filtering
@@ -621,26 +615,25 @@ class GenericBackend(object):
             return True
         for tag in task.get_tags_name():
             if tag in attached_tags:
-                return  True
+                return True
         return False
 
 ###############################################################################
 ### THREADING #################################################################
 ###############################################################################
-
     def __try_launch_setting_thread(self):
         '''
         Helper function to launch the setting thread, if it's not running.
         '''
-        if self.to_set_timer == None and self.is_enabled():
-            self.to_set_timer = threading.Timer(self.timer_timestep, \
-                                        self.launch_setting_thread)
+        if self.to_set_timer is None and self.is_enabled():
+            self.to_set_timer = threading.Timer(self.timer_timestep,
+                                                self.launch_setting_thread)
             self.to_set_timer.start()
 
-    def launch_setting_thread(self, bypass_quit_request = False):
+    def launch_setting_thread(self, bypass_quit_request=False):
         '''
         This function is launched as a separate thread. Its job is to perform
-        the changes that have been issued from GTG core. 
+        the changes that have been issued from GTG core.
         In particular, for each task in the self.to_set queue, a task
         has to be modified or to be created (if the tid is new), and for
         each task in the self.to_remove queue, a task has to be deleted
@@ -656,7 +649,7 @@ class GenericBackend(object):
             except IndexError:
                 break
             tid = task.get_id()
-            if tid  not in self.to_remove:
+            if tid not in self.to_remove:
                 self.set_task(task)
 
         while not self.please_quit or bypass_quit_request:
@@ -665,14 +658,14 @@ class GenericBackend(object):
             except IndexError:
                 break
             self.remove_task(tid)
-        #we release the weak lock
+        # we release the weak lock
         self.to_set_timer = None
 
     def queue_set_task(self, task):
         ''' Save the task in the backend. In particular, it just enqueues the
         task in the self.to_set queue. A thread will shortly run to apply the
         requested changes.
-        
+
         @param task: the task that should be saved
         '''
         tid = task.get_id()
@@ -683,8 +676,8 @@ class GenericBackend(object):
     def queue_remove_task(self, tid):
         '''
         Queues task to be removed. In particular, it just enqueues the
-        task in the self.to_remove queue. A thread will shortly run to apply the
-        requested changes.
+        task in the self.to_remove queue. A thread will shortly run to apply
+        the requested changes.
 
         @param tid: The Task ID of the task to be removed
         '''
@@ -698,7 +691,7 @@ class GenericBackend(object):
         Helper method. Forces the backend to perform all the pending changes.
         It is usually called upon quitting the backend.
         '''
-        if self.to_set_timer != None:
+        if self.to_set_timer is not None:
             self.please_quit = True
             try:
                 self.to_set_timer.cancel()
@@ -708,5 +701,5 @@ class GenericBackend(object):
                 self.to_set_timer.join()
             except:
                 pass
-        self.launch_setting_thread(bypass_quit_request = True)
+        self.launch_setting_thread(bypass_quit_request=True)
         self.save_state()
