@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Getting Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -20,7 +20,7 @@
 '''
 Contains the Backend class for both Tomboy and Gnote
 '''
-#Note: To introspect tomboy, execute:
+# Note: To introspect tomboy, execute:
 #    qdbus org.gnome.Tomboy /org/gnome/Tomboy/RemoteControl
 
 import os
@@ -30,51 +30,48 @@ import dbus
 import datetime
 import unicodedata
 
-from GTG.tools.testingmode       import TestingMode
-from GTG.tools.borg              import Borg
+from GTG.tools.testingmode import TestingMode
+from GTG.tools.borg import Borg
 from GTG.backends.genericbackend import GenericBackend
 from GTG.backends.backendsignals import BackendSignals
-from GTG.backends.syncengine     import SyncEngine, SyncMeme
-from GTG.tools.logger            import Log
-from GTG.tools.watchdog          import Watchdog
-from GTG.tools.interruptible     import interruptible
-from GTG.tools.tags              import extract_tags_from_text
-
+from GTG.backends.syncengine import SyncEngine, SyncMeme
+from GTG.tools.logger import Log
+from GTG.tools.watchdog import Watchdog
+from GTG.tools.interruptible import interruptible
+from GTG.tools.tags import extract_tags_from_text
 
 
 class GenericTomboy(GenericBackend):
     '''Backend class for Tomboy/Gnote'''
-    
 
 ###############################################################################
 ### Backend standard methods ##################################################
 ###############################################################################
-
     def __init__(self, parameters):
         """
         See GenericBackend for an explanation of this function.
         """
         super(GenericTomboy, self).__init__(parameters)
-        #loading the saved state of the synchronization, if any
-        self.data_path = os.path.join('backends/tomboy/', \
+        # loading the saved state of the synchronization, if any
+        self.data_path = os.path.join('backends/tomboy/',
                                       "sync_engine-" + self.get_id())
-        self.sync_engine = self._load_pickled_file(self.data_path, \
+        self.sync_engine = self._load_pickled_file(self.data_path,
                                                    SyncEngine())
-        #if the backend is being tested, we connect to a different DBus
+        # if the backend is being tested, we connect to a different DBus
         # interface to avoid clashing with a running instance of Tomboy
         if TestingMode().get_testing_mode():
-            #just used for testing purposes
+            # just used for testing purposes
             self.BUS_ADDRESS = \
-                    self._parameters["use this fake connection instead"]
+                self._parameters["use this fake connection instead"]
         else:
             self.BUS_ADDRESS = self._BUS_ADDRESS
-        #we let some time pass before considering a tomboy task for importing,
+        # we let some time pass before considering a tomboy task for importing,
         # as the user may still be editing it. Here, we store the Timer objects
         # that will execute after some time after each tomboy signal.
-        #NOTE: I'm not sure if this is the case anymore (but it shouldn't hurt
+        # NOTE: I'm not sure if this is the case anymore (but it shouldn't hurt
         #      anyway). (invernizzi)
         self._tomboy_setting_timers = {}
-        
+
     def initialize(self):
         '''
         See GenericBackend for an explanation of this function.
@@ -84,11 +81,11 @@ class GenericTomboy(GenericBackend):
         with self.DbusWatchdog(self):
             bus = dbus.SessionBus()
             bus.add_signal_receiver(self.on_note_saved,
-                                    dbus_interface = self.BUS_ADDRESS[2],
-                                    signal_name    = "NoteSaved")
+                                    dbus_interface=self.BUS_ADDRESS[2],
+                                    signal_name="NoteSaved")
             bus.add_signal_receiver(self.on_note_deleted,
-                                    dbus_interface = self.BUS_ADDRESS[2],
-                                    signal_name    = "NoteDeleted")
+                                    dbus_interface=self.BUS_ADDRESS[2],
+                                    signal_name="NoteDeleted")
 
     @interruptible
     def start_get_tasks(self):
@@ -100,13 +97,13 @@ class GenericTomboy(GenericBackend):
         tomboy_notes = []
         with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
             with self.DbusWatchdog(self):
-                tomboy_notes = [note_id for note_id in \
+                tomboy_notes = [note_id for note_id in
                                 tomboy.ListAllNotes()]
-        #adding the new ones
+        # adding the new ones
         for note in tomboy_notes:
             self.cancellation_point()
             self._process_tomboy_note(note)
-        #checking if some notes have been deleted while GTG was not running
+        # checking if some notes have been deleted while GTG was not running
         stored_notes_ids = self.sync_engine.get_all_remote()
         for note in set(stored_notes_ids).difference(set(tomboy_notes)):
             self.on_note_deleted(note, None)
@@ -115,10 +112,11 @@ class GenericTomboy(GenericBackend):
         '''Saves the state of the synchronization'''
         self._store_pickled_file(self.data_path, self.sync_engine)
 
-    def quit(self, disable = False):
+    def quit(self, disable=False):
         '''
         See GenericBackend for an explanation of this function.
         '''
+
         def quit_thread():
             while True:
                 try:
@@ -128,13 +126,12 @@ class GenericTomboy(GenericBackend):
                     break
                 timer.cancel()
                 del self._tomboy_setting_timers[key]
-        threading.Thread(target = quit_thread).start()
+        threading.Thread(target=quit_thread).start()
         super(GenericTomboy, self).quit(disable)
 
 ###############################################################################
 ### Something got removed #####################################################
 ###############################################################################
-
     @interruptible
     def on_note_deleted(self, note, something):
         '''
@@ -152,7 +149,7 @@ class GenericTomboy(GenericBackend):
                 return
             if self.datastore.has_task(tid):
                 self.datastore.request_task_deletion(tid)
-                self.break_relationship(remote_id = note)
+                self.break_relationship(remote_id=note)
 
     @interruptible
     def remove_task(self, tid):
@@ -169,7 +166,7 @@ class GenericTomboy(GenericBackend):
                 with self.DbusWatchdog(self):
                     if tomboy.NoteExists(note):
                         tomboy.DeleteNote(note)
-                        self.break_relationship(local_id = tid)
+                        self.break_relationship(local_id=tid)
 
     def _exec_lost_syncability(self, tid, note):
         '''
@@ -183,8 +180,8 @@ class GenericTomboy(GenericBackend):
         '''
         self.cancellation_point()
         meme = self.sync_engine.get_meme_from_remote_id(note)
-        #First of all, the relationship is lost
-        self.sync_engine.break_relationship(remote_id = note)
+        # First of all, the relationship is lost
+        self.sync_engine.break_relationship(remote_id=note)
         if meme.get_origin() == "GTG":
             with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
                 with self.DbusWatchdog(self):
@@ -195,45 +192,48 @@ class GenericTomboy(GenericBackend):
 ###############################################################################
 ### Process tasks #############################################################
 ###############################################################################
-
     def _process_tomboy_note(self, note):
         '''
-        Given a tomboy note, finds out if it must be synced to a GTG note and, 
-        if so, it carries out the synchronization (by creating or updating a GTG
-        task, or deleting itself if the related task has been deleted)
+        Given a tomboy note, finds out if it must be synced to a GTG note and,
+        if so, it carries out the synchronization (by creating or updating a
+        GTG task, or deleting itself if the related task has been deleted)
 
         @param note: a Tomboy note id
         '''
         with self.datastore.get_backend_mutex():
             self.cancellation_point()
             is_syncable = self._tomboy_note_is_syncable(note)
+            has_task = self.datastore.has_task
+            note_exists = self._tomboy_note_exists
             with self.DbusWatchdog(self):
-                action, tid = self.sync_engine.analyze_remote_id(note, \
-                         self.datastore.has_task, \
-                         self._tomboy_note_exists, is_syncable)
+                action, tid = self.sync_engine.analyze_remote_id(note,
+                                                                 has_task,
+                                                                 note_exists,
+                                                                 is_syncable)
             Log.debug("processing tomboy (%s, %s)" % (action, is_syncable))
 
             if action == SyncEngine.ADD:
                 tid = str(uuid.uuid4())
                 task = self.datastore.task_factory(tid)
                 self._populate_task(task, note)
-                self.record_relationship(local_id = tid,\
-                            remote_id = note, \
-                            meme = SyncMeme(task.get_modified(),
-                                            self.get_modified_for_note(note),
-                                            self.get_id()))
+                modified_for = self.get_modified_for_note(note)
+                self.record_relationship(local_id=tid,
+                                         remote_id=note,
+                                         meme=SyncMeme(task.get_modified(),
+                                                       modified_for,
+                                                       self.get_id()))
                 self.datastore.push_task(task)
 
             elif action == SyncEngine.UPDATE:
                 task = self.datastore.get_task(tid)
                 meme = self.sync_engine.get_meme_from_remote_id(note)
                 newest = meme.which_is_newest(task.get_modified(),
-                                     self.get_modified_for_note(note))
+                                              self.get_modified_for_note(note))
                 if newest == "remote":
                     self._populate_task(task, note)
                     meme.set_local_last_modified(task.get_modified())
-                    meme.set_remote_last_modified(\
-                                        self.get_modified_for_note(note))
+                    meme.set_remote_last_modified(
+                        self.get_modified_for_note(note))
                     self.save_state()
 
             elif action == SyncEngine.REMOVE:
@@ -241,7 +241,7 @@ class GenericTomboy(GenericBackend):
                     with self.DbusWatchdog(self):
                         tomboy.DeleteNote(note)
                     try:
-                        self.sync_engine.break_relationship(remote_id = note)
+                        self.sync_engine.break_relationship(remote_id=note)
                     except KeyError:
                         pass
 
@@ -258,16 +258,20 @@ class GenericTomboy(GenericBackend):
         tid = task.get_id()
         with self.datastore.get_backend_mutex():
             with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
+                has_task = self.datastore.has_task
+                has_note = tomboy.NoteExists
+                can_sync = is_syncable
                 with self.DbusWatchdog(self):
-                    action, note = self.sync_engine.analyze_local_id(tid, \
-                              self.datastore.has_task, tomboy.NoteExists, \
-                                                            is_syncable)
+                    action, note = self.sync_engine.analyze_local_id(tid,
+                                                                     has_task,
+                                                                     has_note,
+                                                                     can_sync)
                 Log.debug("processing gtg (%s, %d)" % (action, is_syncable))
 
                 if action == SyncEngine.ADD:
-                    #GTG allows multiple tasks with the same name,
-                    #Tomboy doesn't. we need to handle the renaming
-                    #manually
+                    # GTG allows multiple tasks with the same name,
+                    # Tomboy doesn't. we need to handle the renaming
+                    # manually
                     title = task.get_title()
                     duplicate_counter = 1
                     with self.DbusWatchdog(self):
@@ -275,35 +279,36 @@ class GenericTomboy(GenericBackend):
                         while note == "":
                             duplicate_counter += 1
                             note = tomboy.CreateNamedNote(title + "(%d)" %
-                                                      duplicate_counter)
+                                                          duplicate_counter)
                     if duplicate_counter != 1:
-                        #if we needed to rename, we have to rename also
+                        # if we needed to rename, we have to rename also
                         # the gtg task
                         task.set_title(title + " (%d)" % duplicate_counter)
 
                     self._populate_note(note, task)
-                    self.record_relationship( \
-                        local_id = tid, remote_id = note, \
-                        meme = SyncMeme(task.get_modified(),
-                                        self.get_modified_for_note(note),
-                                        "GTG"))
+                    self.record_relationship(
+                        local_id=tid, remote_id=note,
+                        meme=SyncMeme(task.get_modified(),
+                                      self.get_modified_for_note(note),
+                                      "GTG"))
 
                 elif action == SyncEngine.UPDATE:
-                    meme = self.sync_engine.get_meme_from_local_id(\
-                                                        task.get_id())
+                    meme = self.sync_engine.get_meme_from_local_id(
+                        task.get_id())
+                    modified_for = self.get_modified_for_note(note)
                     newest = meme.which_is_newest(task.get_modified(),
-                                         self.get_modified_for_note(note))
+                                                  modified_for)
                     if newest == "local":
                         self._populate_note(note, task)
                         meme.set_local_last_modified(task.get_modified())
-                        meme.set_remote_last_modified(\
-                                            self.get_modified_for_note(note))
+                        meme.set_remote_last_modified(
+                            self.get_modified_for_note(note))
                         self.save_state()
 
                 elif action == SyncEngine.REMOVE:
                     self.datastore.request_task_deletion(tid)
                     try:
-                        self.sync_engine.break_relationship(local_id = tid)
+                        self.sync_engine.break_relationship(local_id=tid)
                         self.save_state()
                     except KeyError:
                         pass
@@ -314,9 +319,8 @@ class GenericTomboy(GenericBackend):
 ###############################################################################
 ### Helper methods ############################################################
 ###############################################################################
-
     @interruptible
-    def on_note_saved(self,  note):
+    def on_note_saved(self, note):
         '''
         Callback, executed when a tomboy note is saved by Tomboy itself.
         Updates the related GTG task (or creates one, if necessary).
@@ -324,8 +328,9 @@ class GenericTomboy(GenericBackend):
         @param note: the id of the Tomboy note
         '''
         self.cancellation_point()
-        #NOTE: we let some seconds pass before executing the real callback, as
+        # NOTE: we let some seconds pass before executing the real callback, as
         #      the editing of the Tomboy note may still be in progress
+
         @interruptible
         def _execute_on_note_saved(self, note):
             self.cancellation_point()
@@ -341,8 +346,8 @@ class GenericTomboy(GenericBackend):
         except KeyError:
             pass
         finally:
-            timer =threading.Timer(5, _execute_on_note_saved,
-                                   args = (self, note))
+            timer = threading.Timer(5, _execute_on_note_saved,
+                                    args=(self, note))
             self._tomboy_setting_timers[note] = timer
             timer.start()
 
@@ -389,16 +394,16 @@ class GenericTomboy(GenericBackend):
         '''
         with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
             with self.DbusWatchdog(self):
-                return datetime.datetime.fromtimestamp( \
-                                tomboy.GetNoteChangeDate(note))
+                return datetime.datetime.fromtimestamp(
+                    tomboy.GetNoteChangeDate(note))
 
     def _tomboy_split_title_and_text(self, content):
         '''
         Tomboy does not have a "getTitle" and "getText" functions to get the
         title and the text of a note separately. Instead, it has a getContent
         function, that returns both of them.
-        This function splits up the output of getContent into a title string and
-        a text string.
+        This function splits up the output of getContent into a title string
+        and a text string.
 
         @param content: a string, the result of a getContent call
         @returns list: a list composed by [title, text]
@@ -409,7 +414,7 @@ class GenericTomboy(GenericBackend):
             return content, unicode("")
         title = content[: end_of_title]
         if len(content) > end_of_title:
-            return title, content[end_of_title +1 :]
+            return title, content[end_of_title + 1:]
         else:
             return title, unicode("")
 
@@ -420,16 +425,16 @@ class GenericTomboy(GenericBackend):
         @param task: a GTG Task
         @param note: a Tomboy note
         '''
-        #add tags objects (it's not enough to have @tag in the text to add a
+        # add tags objects (it's not enough to have @tag in the text to add a
         # tag
         with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
             with self.DbusWatchdog(self):
                 content = tomboy.GetNoteContents(note)
-        #update the tags list
+        # update the tags list
         task.set_only_these_tags(extract_tags_from_text(content))
-        #extract title and text
+        # extract title and text
         [title, text] = self._tomboy_split_title_and_text(unicode(content))
-        #Tomboy speaks unicode, we don't
+        # Tomboy speaks unicode, we don't
         title = unicodedata.normalize('NFKD', title).encode('ascii', 'ignore')
         text = unicodedata.normalize('NFKD', text).encode('ascii', 'ignore')
         task.set_title(title)
@@ -444,27 +449,25 @@ class GenericTomboy(GenericBackend):
         @param task: a GTG Task
         '''
         title = task.get_title()
-        tested_title = title
-        duplicate_counter = 1
         with self.TomboyConnection(self, *self.BUS_ADDRESS) as tomboy:
             with self.DbusWatchdog(self):
-                tomboy.SetNoteContents(note, title + '\n' + \
-                                       task.get_excerpt(strip_tags = False))
+                tomboy.SetNoteContents(note, title + '\n' +
+                                       task.get_excerpt(strip_tags=False))
 
     def break_relationship(self, *args, **kwargs):
         '''
         Proxy method for SyncEngine.break_relationship, which also saves the
         state of the synchronization.
         '''
-        #tomboy passes Dbus.String objects, which are not pickable. We convert
+        # tomboy passes Dbus.String objects, which are not pickable. We convert
         # those to unicode
         if "remote_id" in kwargs:
             kwargs["remote_id"] = unicode(kwargs["remote_id"])
         try:
             self.sync_engine.break_relationship(*args, **kwargs)
-            #we try to save the state at each change in the sync_engine:
-            #it's slower, but it should avoid widespread task
-            #duplication
+            # we try to save the state at each change in the sync_engine:
+            # it's slower, but it should avoid widespread task
+            # duplication
             self.save_state()
         except KeyError:
             pass
@@ -474,23 +477,20 @@ class GenericTomboy(GenericBackend):
         Proxy method for SyncEngine.break_relationship, which also saves the
         state of the synchronization.
         '''
-        #tomboy passes Dbus.String objects, which are not pickable. We convert
+        # tomboy passes Dbus.String objects, which are not pickable. We convert
         # those to unicode
         if "remote_id" in kwargs:
             kwargs["remote_id"] = unicode(kwargs["remote_id"])
 
         self.sync_engine.record_relationship(*args, **kwargs)
-        #we try to save the state at each change in the sync_engine:
-        #it's slower, but it should avoid widespread task
-        #duplication
+        # we try to save the state at each change in the sync_engine:
+        # it's slower, but it should avoid widespread task
+        # duplication
         self.save_state()
 
 ###############################################################################
 ### Connection handling #######################################################
 ###############################################################################
-
-
-
     class TomboyConnection(Borg):
         '''
         TomboyConnection creates a connection to TOMBOY via DBus and
@@ -501,7 +501,6 @@ class GenericTomboy(GenericBackend):
                 #do something
         '''
 
-
         def __init__(self, backend, bus_name, bus_path, bus_interface):
             '''
             Sees if a TomboyConnection object already exists. If so, since we
@@ -513,11 +512,11 @@ class GenericTomboy(GenericBackend):
             @param backend: a reference to a Backend
             @param bus_name: the DBus address of Tomboy
             @param bus_path: the DBus path of Tomboy RemoteControl
-            @param bus_interface: the DBus address of Tomboy RemoteControl 
+            @param bus_interface: the DBus address of Tomboy RemoteControl
             '''
             super(GenericTomboy.TomboyConnection, self).__init__()
             if hasattr(self, "tomboy_connection_is_ok") and \
-                                self.tomboy_connection_is_ok:
+                    self.tomboy_connection_is_ok:
                 return
             self.backend = backend
             self.tomboy_connection_is_ok = True
@@ -537,7 +536,6 @@ class GenericTomboy(GenericBackend):
             @returns: dbus.Interface
             '''
             return self.tomboy
-                
 
         def __exit__(self, exception_type, value, traceback):
             '''
@@ -551,38 +549,36 @@ class GenericTomboy(GenericBackend):
             @returns: False if some exception must be re-raised.
             '''
             if isinstance(value, dbus.DBusException) or \
-                not self.tomboy_connection_is_ok:
+                    not self.tomboy_connection_is_ok:
                 self.tomboy_failed()
                 return True
             else:
                 return False
-        
+
         def tomboy_failed(self):
             """ Handle failed tomboy connection.
 
             Disable backend and show error in notification bar """
             self.tomboy_connection_is_ok = False
             BackendSignals().backend_failed(self.backend.get_id(),
-                BackendSignals.ERRNO_DBUS)
-            self.backend.quit(disable = True)
-
+                                            BackendSignals.ERRNO_DBUS)
+            self.backend.quit(disable=True)
 
     class DbusWatchdog(Watchdog):
         '''
         A simple watchdog to detect stale dbus connections
         '''
 
-
         def __init__(self, backend):
             '''
-            Simple constructor, which sets _when_taking_too_long as the function
-            to run when the connection is taking too long.
+            Simple constructor, which sets _when_taking_too_long as the
+            function to run when the connection is taking too long.
 
             @param backend: a Backend object
             '''
             self.backend = backend
             super(GenericTomboy.DbusWatchdog, self).__init__(
-                        3, self._when_taking_too_long)
+                3, self._when_taking_too_long)
 
         def _when_taking_too_long(self):
             '''
@@ -592,5 +588,5 @@ class GenericTomboy(GenericBackend):
             Log.error("Dbus connection is taking too long for the Tomboy/Gnote"
                       "backend!")
             BackendSignals().backend_failed(self.backend.get_id(),
-                            BackendSignals.ERRNO_DBUS)
-            self.backend.quit(disable = True)
+                                            BackendSignals.ERRNO_DBUS)
+            self.backend.quit(disable=True)
