@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -16,31 +16,30 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-
-TAG_XMLFILE = "tags.xml"
-TAG_XMLROOT = "tagstore"
-
 """
 Contains the Datastore object, which is the manager of all the active backends
 (both enabled and disabled ones)
 """
 
+TAG_XMLFILE = "tags.xml"
+TAG_XMLROOT = "tagstore"
+
 import threading
 import uuid
 import os.path
 from collections import deque
 
-from GTG.core import requester
-from GTG.core.task import Task
-from GTG.core.tag import Tag
-from GTG.core import CoreConfig
-from GTG.core.treefactory import TreeFactory
-from GTG.tools.logger import Log
-from GTG.backends.genericbackend import GenericBackend
-from GTG.tools import cleanxml
 from GTG.backends.backendsignals import BackendSignals
-from GTG.tools.borg import Borg
+from GTG.backends.genericbackend import GenericBackend
+from GTG.core import CoreConfig
+from GTG.core import requester
 from GTG.core.search import parse_search_query, search_filter, InvalidQuery
+from GTG.core.tag import Tag
+from GTG.core.task import Task
+from GTG.core.treefactory import TreeFactory
+from GTG.tools import cleanxml
+from GTG.tools.borg import Borg
+from GTG.tools.logger import Log
 
 
 class DataStore(object):
@@ -56,40 +55,40 @@ class DataStore(object):
         """
         Initializes a DataStore object
         """
-        self.backends = {} #dictionary {backend_name_string: Backend instance}
+        # dictionary {backend_name_string: Backend instance}
+        self.backends = {}
         self.treefactory = TreeFactory()
-        self.__tasks = self.treefactory.get_tasks_tree()
+        self._tasks = self.treefactory.get_tasks_tree()
         self.requester = requester.Requester(self, global_conf)
         self.tagfile = None
-        self.__tagstore = self.treefactory.get_tags_tree(self.requester)
+        self._tagstore = self.treefactory.get_tags_tree(self.requester)
         self.load_tag_tree()
         self._backend_signals = BackendSignals()
-        self.please_quit = False #when turned to true, all pending operation
-                                 # should be completed and then GTG should quit
-        self.is_default_backend_loaded = False #the default backend must be
-                                               # loaded before anyone else.
-                                               # This turns to True when the
-                                               # default backend loading has
-                                               # finished.
-        self._backend_signals.connect('default-backend-loaded', \
+
+        # Flag when turned to true, all pending operation should be
+        # completed and then GTG should quit
+        self.please_quit = False
+
+        # The default backend must be loaded first. This flag turns to True
+        # when the default backend loading has finished.
+        self.is_default_backend_loaded = False
+        self._backend_signals.connect('default-backend-loaded',
                                       self._activate_non_default_backends)
         self.filtered_datastore = FilteredDataStore(self)
         self._backend_mutex = threading.Lock()
 
-    ##########################################################################
-    ### Helper functions (get_ methods for Datastore embedded objects)
-    ##########################################################################
+    ### Accessor to embedded objects in DataStore ############################
     def get_tagstore(self):
         """
-        Helper function to obtain the Tagstore associated with this DataStore
+        Return the Tagstore associated with this DataStore
 
         @return GTG.core.tagstore.TagStore: the tagstore object
         """
-        return self.__tagstore
+        return self._tagstore
 
     def get_requester(self):
         """
-        Helper function to get the Requester associate with this DataStore
+        Return the Requester associate with this DataStore
 
         @returns GTG.core.requester.Requester: the requester associated with
                                                this datastore
@@ -98,44 +97,46 @@ class DataStore(object):
 
     def get_tasks_tree(self):
         """
-        Helper function to get a Tree with all the tasks contained in this
-        Datastore.
+        Return the Tree with all the tasks contained in this Datastore
 
         @returns GTG.core.tree.Tree: a task tree (the main one)
         """
-        return self.__tasks
+        return self._tasks
 
-    ##########################################################################
-    ### Tags functions
-    ##########################################################################
+    ### Tags functions ########################################################
     def _add_new_tag(self, name, tag, filter_func, parameters, parent_id=None):
         """ Add tag into a tree """
         name = name.encode("UTF-8")
-        if self.__tagstore.has_node(name):
+        if self._tagstore.has_node(name):
             raise IndexError('tag %s was already in the datastore' % name)
 
-        self.__tasks.add_filter(name, filter_func, parameters=parameters)
-        self.__tagstore.add_node(tag, parent_id=parent_id)
+        self._tasks.add_filter(name, filter_func, parameters=parameters)
+        self._tagstore.add_node(tag, parent_id=parent_id)
         tag.set_save_callback(self.save)
 
     def new_tag(self, name, attributes={}):
-        """ Create a new tag and return it """
+        """
+        Create a new tag
 
+        @returns GTG.core.tag.Tag: the new tag
+        """
         name = name.encode("UTF-8")
         parameters = {'tag': name}
         tag = Tag(name, req=self.requester, attributes=attributes)
-
         self._add_new_tag(name, tag, self.treefactory.tag_filter, parameters)
-        Log.debug("*** tag added %s ***" % name)
         return tag
 
     def new_search_tag(self, name, query, attributes={}):
-        """ Create a new search tag """
+        """
+        Create a new search tag
+
+        @returns GTG.core.tag.Tag: the new search tag/None for a invalid query
+        """
         try:
             parameters = parse_search_query(query)
         except InvalidQuery, e:
             Log.warning("Problem with parsing query '%s' (skipping): %s" %
-                (query, e.message))
+                       (query, e.message))
             return None
 
         name = name.encode("UTF-8")
@@ -146,17 +147,15 @@ class DataStore(object):
         init_attr["query"] = query
 
         tag = Tag(name, req=self.requester, attributes=init_attr)
-
-        self._add_new_tag(name, tag, search_filter,
-            parameters, parent_id = CoreConfig.SEARCH_TAG)
-        Log.debug("*** view added %s ***" % name)
+        self._add_new_tag(name, tag, search_filter, parameters,
+                          parent_id=CoreConfig.SEARCH_TAG)
         self.save_tagtree()
         return tag
 
     def remove_tag(self, name):
         """ Removes a tag from the tagtree """
-        if self.__tagstore.has_node(name):
-            self.__tagstore.del_node(name)
+        if self._tagstore.has_node(name):
+            self._tagstore.del_node(name)
             self.save_tagtree()
         else:
             raise IndexError("There is no tag %s" % name)
@@ -188,21 +187,20 @@ class DataStore(object):
             newname = '_' + newname
 
         label, num = newname, 1
-        while self.__tagstore.has_node(label):
+        while self._tagstore.has_node(label):
             num += 1
             label = newname + " " + str(num)
 
         self.new_search_tag(label, query)
 
     def get_tag(self, tagname):
-        #The following is wrong, as we have special tags that do not start with
-        # @. I'm leaving this here temporary to help in merging (as it will
-        # probably generate a conflict). Remove at will after merging
-        # (invernizzi)
-        #if tagname[0] != "@":
-        #    tagname = "@" + tagname
-        if self.__tagstore.has_node(tagname):
-            return self.__tagstore.get_node(tagname)
+        """
+        Returns tag object
+
+        @return GTG.core.tag.Tag
+        """
+        if self._tagstore.has_node(tagname):
+            return self._tagstore.get_node(tagname)
         else:
             return None
 
@@ -210,7 +208,6 @@ class DataStore(object):
         """
         Loads the tag tree from a xml file
         """
-        # Loading tags
         tagfile = os.path.join(CoreConfig().get_data_dir(), TAG_XMLFILE)
         doc, xmlstore = cleanxml.openxmlfile(tagfile, TAG_XMLROOT)
         for t in xmlstore.childNodes:
@@ -236,19 +233,19 @@ class DataStore(object):
         self.tagfile = tagfile
 
     def save_tagtree(self):
-        """ saves the tag tree to a xml file """
+        """ Saves the tag tree to an XML file """
         if not self.tagfile:
             return
 
         doc, xmlroot = cleanxml.emptydoc(TAG_XMLROOT)
-        tags = self.__tagstore.get_main_view().get_all_nodes()
+        tags = self._tagstore.get_main_view().get_all_nodes()
         already_saved = []
 
         for tagname in tags:
             if tagname in already_saved:
                 continue
 
-            tag = self.__tagstore.get_node(tagname)
+            tag = self._tagstore.get_node(tagname)
             attributes = tag.get_all_attributes(butname=True, withparent=True)
             if "special" in attributes or len(attributes) == 0:
                 continue
@@ -269,26 +266,24 @@ class DataStore(object):
 
         cleanxml.savexml(self.tagfile, doc, backup=True)
 
-    ##########################################################################
-    ### Tasks functions
-    ##########################################################################
+    ### Tasks functions #######################################################
     def get_all_tasks(self):
         """
-        Returns list of all keys of open tasks
+        Returns list of all keys of active tasks
 
         @return a list of strings: a list of task ids
         """
-        return self.__tasks.get_main_view().get_all_nodes()
+        return self._tasks.get_main_view().get_all_nodes()
 
     def has_task(self, tid):
         """
-        Returns true if the tid is among the open or closed tasks for
+        Returns true if the tid is among the active or closed tasks for
         this DataStore, False otherwise.
 
         @param tid: Task ID to search for
         @return bool: True if the task is present
         """
-        return self.__tasks.has_node(tid)
+        return self._tasks.has_node(tid)
 
     def get_task(self, tid):
         """
@@ -300,11 +295,11 @@ class DataStore(object):
         or not
         """
         if self.has_task(tid):
-            return self.__tasks.get_node(tid)
+            return self._tasks.get_node(tid)
         else:
-            #Log.error("requested non-existent task %s" % tid)
-            #This is not an error: it is normal to request a task which
-            #might not exist yet.
+            # Log.error("requested non-existent task %s" % tid)
+            # This is not an error: it is normal to request a task which
+            # might not exist yet.
             return None
 
     def task_factory(self, tid, newtask=False):
@@ -327,7 +322,7 @@ class DataStore(object):
         @return: The task object that was created.
         """
         task = self.task_factory(str(uuid.uuid4()), True)
-        self.__tasks.add_node(task)
+        self._tasks.add_node(task)
         return task
 
     def push_task(self, task):
@@ -342,14 +337,14 @@ class DataStore(object):
         """
 
         def adding(task):
-            self.__tasks.add_node(task)
+            self._tasks.add_node(task)
             task.set_loaded()
             if self.is_default_backend_loaded:
                 task.sync()
         if self.has_task(task.get_id()):
             return False
         else:
-            #Thread protection
+            # Thread protection
             adding(task)
             return True
 
@@ -398,32 +393,32 @@ class DataStore(object):
                 Log.error("registering a backend without pid.")
                 return None
             backend = backend_dic["backend"]
-            #Checking that is a new backend
+            # Checking that is a new backend
             if backend.get_id() in self.backends:
                 Log.error("registering already registered backend")
                 return None
-            #creating the TaskSource which will wrap the backend,
+            # creating the TaskSource which will wrap the backend,
             # filtering the tasks that should hit the backend.
             source = TaskSource(requester=self.requester,
                                 backend=backend,
                                 datastore=self.filtered_datastore)
             self.backends[backend.get_id()] = source
-            #we notify that a new backend is present
+            # we notify that a new backend is present
             self._backend_signals.backend_added(backend.get_id())
-            #saving the backend in the correct dictionary (backends for enabled
-            # backends, disabled_backends for the disabled ones)
-            #this is useful for retro-compatibility
+            # saving the backend in the correct dictionary (backends for
+            # enabled backends, disabled_backends for the disabled ones)
+            # this is useful for retro-compatibility
             if not GenericBackend.KEY_ENABLED in backend_dic:
                 source.set_parameter(GenericBackend.KEY_ENABLED, True)
             if not GenericBackend.KEY_DEFAULT_BACKEND in backend_dic:
                 source.set_parameter(GenericBackend.KEY_DEFAULT_BACKEND, True)
-            #if it's enabled, we initialize it
+            # if it's enabled, we initialize it
             if source.is_enabled() and \
-               (self.is_default_backend_loaded or source.is_default()):
+                    (self.is_default_backend_loaded or source.is_default()):
                 source.initialize(connect_signals=False)
-                #Filling the backend
-                #Doing this at start is more efficient than
-                #after the GUI is launched
+                # Filling the backend
+                # Doing this at start is more efficient than
+                # after the GUI is launched
                 source.start_get_tasks()
             return source
         else:
@@ -464,7 +459,7 @@ class DataStore(object):
             self.flush_all_tasks(backend.get_id())
 
         thread = threading.Thread(target=__backend_startup,
-                                          args=(self, backend))
+                                  args=(self, backend))
         thread.setDaemon(True)
         thread.start()
 
@@ -485,18 +480,18 @@ class DataStore(object):
         if backend_id in self.backends:
             backend = self.backends[backend_id]
             current_state = backend.is_enabled()
-            if current_state == True and state == False:
-                #we disable the backend
-                #FIXME!!!
-                threading.Thread(target=backend.quit, \
+            if current_state is True and state is False:
+                # we disable the backend
+                # FIXME!!!
+                threading.Thread(target=backend.quit,
                                  kwargs={'disable': True}).start()
-            elif current_state == False and state == True:
-                if self.is_default_backend_loaded == True:
+            elif current_state is False and state is True:
+                if self.is_default_backend_loaded is True:
                     self._backend_startup(backend)
                 else:
-                    #will be activated afterwards
+                    # will be activated afterwards
                     backend.set_parameter(GenericBackend.KEY_ENABLED,
-                                       True)
+                                          True)
 
     def remove_backend(self, backend_id):
         """
@@ -508,13 +503,13 @@ class DataStore(object):
             backend = self.backends[backend_id]
             if backend.is_enabled():
                 self.set_backend_enabled(backend_id, False)
-            #FIXME: to keep things simple, backends are not notified that they
+            # FIXME: to keep things simple, backends are not notified that they
             #       are completely removed (they think they're just
             #       deactivated). We should add a "purge" call to backend to
             #       let them know that they're removed, so that they can
             #       remove all the various files they've created. (invernizzi)
 
-            #we notify that the backend has been deleted
+            # we notify that the backend has been deleted
             self._backend_signals.backend_removed(backend.get_id())
             del self.backends[backend_id]
 
@@ -562,37 +557,37 @@ class DataStore(object):
         except Exception:
             pass
         doc, xmlconfig = cleanxml.emptydoc("config")
-        #we ask all the backends to quit first.
+        # we ask all the backends to quit first.
         if quit:
-            #we quit backends in parallel
+            # we quit backends in parallel
             threads_dic = {}
             for b in self.get_all_backends():
                 thread = threading.Thread(target=b.quit)
                 threads_dic[b.get_id()] = thread
                 thread.start()
             for backend_id, thread in threads_dic.iteritems():
-                #after 20 seconds, we give up
+                # after 20 seconds, we give up
                 thread.join(20)
                 if thread.isAlive():
                     Log.error("The %s backend stalled while quitting",
                               backend_id)
-        #we save the parameters
+        # we save the parameters
         for b in self.get_all_backends(disabled=True):
             t_xml = doc.createElement("backend")
             for key, value in b.get_parameters().iteritems():
                 if key in ["backend", "xmlobject"]:
-                    #We don't want parameters, backend, xmlobject: we'll create
-                    # them at next startup
+                    # We don't want parameters, backend, xmlobject:
+                    # we'll create them at next startup
                     continue
                 param_type = b.get_parameter_type(key)
                 value = b.cast_param_type_to_string(param_type, value)
                 t_xml.setAttribute(str(key), value)
-            #Saving all the projects at close
+            # Saving all the projects at close
             xmlconfig.appendChild(t_xml)
         datadir = CoreConfig().get_data_dir()
         datafile = os.path.join(datadir, CoreConfig.DATA_FILE)
         cleanxml.savexml(datafile, doc, backup=True)
-        #Saving the tagstore
+        # Saving the tagstore
         self.save_tagtree()
 
     def request_task_deletion(self, tid):
@@ -677,8 +672,9 @@ class TaskSource():
             task_tags = set(task.get_tags_name())
             return task_tags.intersection(tags_to_match_set)
 
-        return lambda task: backend_filter(self.requester, task, \
-                        {"tags": set(self.backend.get_attached_tags())})
+        attached_tags = self.backend.get_attached_tags()
+        return lambda task: backend_filter(self.requester, task,
+                                           {"tags": set(attached_tags)})
 
     def should_task_id_be_stored(self, task_id):
         """
@@ -687,8 +683,8 @@ class TaskSource():
         @param task_id: a task id
         @returns bool: True if the task should be stored
         """
-        #task = self.req.get_task(task_id)
-        #FIXME: it will be a lot easier to add, instead,
+        # task = self.req.get_task(task_id)
+        # FIXME: it will be a lot easier to add, instead,
         # a filter to a tree and check that this task is well in the tree
 #        return self.task_filter(task)
         return True
@@ -724,12 +720,12 @@ class TaskSource():
                 tid = self.to_set.pop()
             except IndexError:
                 break
-            #we check that the task is not already marked for deletion
-            #and that it's still to be stored in this backend
-            #NOTE: no need to lock, we're reading
+            # we check that the task is not already marked for deletion
+            # and that it's still to be stored in this backend
+            # NOTE: no need to lock, we're reading
             if tid not in self.to_remove and \
                     self.should_task_id_be_stored(tid) and \
-                   self.req.has_task(tid):
+                    self.req.has_task(tid):
                 task = self.req.get_task(tid)
                 self.backend.queue_set_task(task)
         while not self.please_quit or bypass_please_quit:
@@ -738,7 +734,7 @@ class TaskSource():
             except IndexError:
                 break
             self.backend.queue_remove_task(tid)
-        #we release the weak lock
+        # we release the weak lock
         self.to_set_timer = None
 
     def queue_remove_task(self, tid, path=None):
@@ -756,9 +752,9 @@ class TaskSource():
         """
         Helper function to launch the setting thread, if it's not running
         """
-        if self.to_set_timer == None and not self.please_quit:
-            self.to_set_timer = threading.Timer(self.timer_timestep, \
-                                        self.launch_setting_thread)
+        if self.to_set_timer is None and not self.please_quit:
+            self.to_set_timer = threading.Timer(self.timer_timestep,
+                                                self.launch_setting_thread)
             self.to_set_timer.setDaemon(True)
             self.to_set_timer.start()
 
@@ -792,15 +788,15 @@ class TaskSource():
         """
         if self.add_task_handle:
             self.tasktree.deregister_cllbck('node-added',
-                self.set_task_handle)
+                                            self.set_task_handle)
             self.add_task_handle = None
         if self.set_task_handle:
             self.tasktree.deregister_cllbck('node-modified',
-                self.set_task_handle)
+                                            self.set_task_handle)
             self.set_task_handle = None
-        if  self.remove_task_handle:
+        if self.remove_task_handle:
             self.tasktree.deregister_cllbck('node-deleted',
-                self.remove_task_handle)
+                                            self.remove_task_handle)
             self.remove_task_handle = None
 
     def sync(self):
