@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Getting Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -19,8 +19,8 @@
 import imp
 import os
 import types
+import ConfigParser
 
-from configobj import ConfigObj
 import dbus
 
 from GTG.tools.borg import Borg
@@ -42,16 +42,16 @@ class Plugin(object):
     missing_dbus = []
 
     def __init__(self, info, module_path):
-        """Initialize the Plugin using a ConfigObj."""
+        """Initialize the Plugin using a ConfigParser."""
         info_fields = {
-          'module_name': 'Module',
-          'full_name': 'Name',
-          'version': 'Version',
-          'authors': 'Authors',
-          'short_description': 'Short-description',
-          'description': 'Description',
-          'module_depends': 'Dependencies',
-          'dbus_depends': 'Dbus-dependencies',
+            'module_name': 'module',
+            'full_name': 'name',
+            'version': 'version',
+            'authors': 'authors',
+            'short_description': 'short-description',
+            'description': 'description',
+            'module_depends': 'dependencies',
+            'dbus_depends': 'dbus-dependencies',
         }
         for attr, field in info_fields.iteritems():
             try:
@@ -59,7 +59,12 @@ class Plugin(object):
             except KeyError:
                 setattr(self, attr, [])
         # turn the enabled attribute into a bool
-        self.enabled = eval(info['Enabled'])
+        self.enabled = info['enabled'].lower() == "true"
+        # ensure the module dependencies are a list
+        if isinstance(self.module_depends, str):
+            self.module_depends = self.module_depends.split(',')
+            if not self.module_depends[-1]:
+                self.module_depends = self.module_depends[:-1]
         # ensure the dbus dependencies are a list
         if isinstance(self.dbus_depends, str):
             self.dbus_depends = [self.dbus_depends]
@@ -151,7 +156,7 @@ class PluginEngine(Borg):
         """
         super(PluginEngine, self).__init__()
         if hasattr(self, "plugin_path"):
-            #Borg has already been initialized, skip
+            # Borg has already been initialized, skip
             return
 
         self.plugin_path = plugin_path
@@ -164,8 +169,10 @@ class PluginEngine(Borg):
             for f in os.listdir(path):
                 info_file = os.path.join(path, f)
                 if os.path.isfile(info_file) and f.endswith('.gtg-plugin'):
-                    info = ConfigObj(info_file)
-                    p = Plugin(info["GTG Plugin"], self.plugin_path)
+                    info = ConfigParser.ConfigParser()
+                    info.read(info_file)
+                    info = dict(info.items("GTG Plugin"))
+                    p = Plugin(info, self.plugin_path)
                     self.plugins[p.module_name] = p
 
     def get_plugin(self, module_name):
@@ -231,6 +238,8 @@ class PluginEngine(Borg):
                 for api in self.plugin_apis:
                     if hasattr(plugin.instance, "deactivate"):
                         plugin.instance.deactivate(api)
+                        classname = plugin.instance.deactivate.im_class
+                        api.remove_active_selection_changed_callback(classname)
                     if api.is_editor():
                         if hasattr(plugin.instance, "onTaskClosed"):
                             plugin.instance.onTaskClosed(api)
@@ -257,7 +266,7 @@ class PluginEngine(Borg):
             if hasattr(plugin.instance, 'onTaskClosed'):
                 plugin.instance.onTaskClosed(plugin_api)
 
-#FIXME: What are these for? must check someday! (invernizzi)
+# FIXME: What are these for? must check someday! (invernizzi)
     def recheck_plugins(self, plugin_apis):
         """Check plugins to make sure their states are consistent.
 
@@ -267,8 +276,8 @@ class PluginEngine(Borg):
             try:
                 if plugin.instance and plugin.enabled and plugin.active:
                     self.deactivate_plugins(self.plugin_apis, [plugin])
-                elif plugin.instance is None and plugin.enabled and (not
-                  plugin.active):
+                elif plugin.instance is None and plugin.enabled and \
+                        (not plugin.active):
                     if plugin.error:
                         plugin.enabled = False
                     else:
