@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -20,17 +20,18 @@
 """
 task.py contains the Task class which represents (guess what) a task
 """
-from datetime         import datetime
+from datetime import datetime
 import cgi
 import re
 import uuid
 import xml.dom.minidom
 import xml.sax.saxutils as saxutils
 
-from GTG                     import _
-from GTG.tools.dates         import Date
-from GTG.tools.logger        import Log
-from liblarch                import TreeNode
+from GTG import _
+from GTG.tools.dates import Date
+from GTG.tools.logger import Log
+from liblarch import TreeNode
+from GTG.tools.tags import extract_tags_from_text
 
 
 class Task(TreeNode):
@@ -44,15 +45,15 @@ class Task(TreeNode):
 
     def __init__(self, ze_id, requester, newtask=False):
         TreeNode.__init__(self, ze_id)
-        #the id of this task in the project should be set
-        #tid is a string ! (we have to choose a type and stick to it)
+        # the id of this task in the project should be set
+        # tid is a string ! (we have to choose a type and stick to it)
         assert(isinstance(ze_id, str) or isinstance(ze_id, unicode))
         self.tid = str(ze_id)
         self.set_uuid(uuid.uuid4())
         self.remote_ids = {}
         self.content = ""
         self.title = _("My new task")
-        #available status are: Active - Done - Dismiss - Note
+        # available status are: Active - Done - Dismiss - Note
         self.status = self.STA_ACTIVE
         self.closed_date = Date.no_date()
         self.due_date = Date.no_date()
@@ -62,9 +63,9 @@ class Task(TreeNode):
         self.tags = []
         self.req = requester
         self.__main_treeview = requester.get_main_view()
-        #If we don't have a newtask, we will have to load it.
+        # If we don't have a newtask, we will have to load it.
         self.loaded = newtask
-        #Should not be necessary with the new backends
+        # Should not be necessary with the new backends
 #        if self.loaded:
 #            self.req._task_loaded(self.tid)
         self.attributes = {}
@@ -74,7 +75,7 @@ class Task(TreeNode):
         return self.loaded
 
     def set_loaded(self, signal=True):
-        #avoid doing it multiple times
+        # avoid doing it multiple times
         if not self.loaded:
             self.loaded = True
 
@@ -91,7 +92,7 @@ class Task(TreeNode):
         self.uuid = str(value)
 
     def get_uuid(self):
-        #NOTE: Transitional if switch, needed to add
+        # NOTE: Transitional if switch, needed to add
         #      the uuid field to tasks created before
         #      adding this field to the task description.
         if self.uuid == "":
@@ -121,11 +122,11 @@ class Task(TreeNode):
     def get_title(self):
         return self.title
 
-    #Return True if the title was changed.
-    #False if the title was already the same.
+    # Return True if the title was changed.
+    # False if the title was already the same.
     def set_title(self, title):
-        #We should check for other task with the same title
-        #In that case, we should add a number (like Tomboy does)
+        # We should check for other task with the same title
+        # In that case, we should add a number (like Tomboy does)
         old_title = self.title
         if isinstance(title, str):
             title = title.decode('utf8')
@@ -133,14 +134,14 @@ class Task(TreeNode):
             self.title = title.strip('\t\n')
         else:
             self.title = "(no title task)"
-        #Avoid unnecessary sync
+        # Avoid unnecessary sync
         if self.title != old_title:
             self.sync()
             return True
         else:
             return False
 
-    #TODO : should we merge this function with set_title ?
+    # TODO : should we merge this function with set_title ?
     def set_complex_title(self, text, tags=[]):
         if tags:
             assert(isinstance(tags[0], str))
@@ -148,7 +149,7 @@ class Task(TreeNode):
         defer_date = Date.no_date()
         if text:
             # Get tags in the title
-            for match in re.findall(r'(?:^|[\s])(@\w+)', text, re.UNICODE):
+            for match in extract_tags_from_text(text):
                 tags.append(match)
             # Get attributes
             regexp = r'([\s]*)([\w-]+):\s*([^\s]+)'
@@ -157,17 +158,18 @@ class Task(TreeNode):
                 valid_attribute = True
                 if attribute.lower() in ["tags", _("tags"), "tag", _("tag")]:
                     for tag in args.split(","):
-                        if not tag.startswith("@"):
-                            tag = "@" + tag
-                        tags.append(tag)
+                        if not tag.strip() == "@" and not tag.strip() == "":
+                            if not tag.startswith("@"):
+                                tag = "@" + tag
+                            tags.append(tag)
                 elif attribute.lower() in ["defer", _("defer"), "start",
-                        _("start")]:
+                                           _("start")]:
                     try:
                         defer_date = Date.parse(args)
                     except ValueError:
                         valid_attribute = False
                 elif attribute.lower() == "due" or \
-                     attribute.lower() == _("due"):
+                        attribute.lower() == _("due"):
                     try:
                         due_date = Date.parse(args)
                     except:
@@ -194,42 +196,42 @@ class Task(TreeNode):
     def set_status(self, status, donedate=None):
         old_status = self.status
         self.can_be_deleted = False
-        #No need to update children or whatever if the task is not loaded
+        # No need to update children or whatever if the task is not loaded
         if status and self.is_loaded():
-            #we first modify the status of the children
-            #If Done, we set the done date
+            # we first modify the status of the children
+            # If Done, we set the done date
             if status in [self.STA_DONE, self.STA_DISMISSED]:
                 for c in self.get_subtasks():
                     if c.get_status() in [self.STA_ACTIVE]:
                         c.set_status(status, donedate=donedate)
-            #If we mark a task as Active and that some parent are not
-            #Active, we break the parent/child relation
-            #It has no sense to have an active subtask of a done parent.
+            # If we mark a task as Active and that some parent are not
+            # Active, we break the parent/child relation
+            # It has no sense to have an active subtask of a done parent.
             # (old_status check is necessary to avoid false positive a start)
             elif status in [self.STA_ACTIVE] and\
-                 old_status in [self.STA_DONE, self.STA_DISMISSED]:
+                    old_status in [self.STA_DONE, self.STA_DISMISSED]:
                 if self.has_parent():
                     for p_tid in self.get_parents():
                         par = self.req.get_task(p_tid)
                         if par.is_loaded() and par.get_status() in\
-                           [self.STA_DONE, self.STA_DISMISSED]:
-                            #we can either break the parent/child relationship
-                            #self.remove_parent(p_tid)
-                            #or restore the parent too
+                                [self.STA_DONE, self.STA_DISMISSED]:
+                            # we can either break the parent/child relationship
+                            # self.remove_parent(p_tid)
+                            # or restore the parent too
                             par.set_status(self.STA_ACTIVE)
-                #We dont mark the children as Active because
-                #They might be already completed after all
+                # We dont mark the children as Active because
+                # They might be already completed after all
 
-        #then the task itself
+        # then the task itself
         if status:
             self.status = status
 
         # Set closing date
         if status and status in [self.STA_DONE, self.STA_DISMISSED]:
-            #to the specified date (if any)
+            # to the specified date (if any)
             if donedate:
                 self.closed_date = donedate
-            #or to today
+            # or to today
             else:
                 self.closed_date = Date.today()
         self.sync()
@@ -265,8 +267,8 @@ class Task(TreeNode):
     # Date constraints
     #
     # Those are the following:
-    #   - children of a task cannot have a task due date that happens later than
-    #     the task's due date
+    #   - children of a task cannot have a task due date that happens later
+    #     than the task's due date
     #   - ancestors of a task cannot have a due that happens before the
     #     task's due date (this is the reverse constraint from the first one)
     #   - a task's start date cannot happen later than this task's due date
@@ -274,24 +276,23 @@ class Task(TreeNode):
     # Tasks with undefined or fuzzy due dates
     #
     # Task with no due date (="undefined" tasks) or tasks with fuzzy start/due
-    # dates are not subject to constraints. Furthermore, they are "transparent".
-    # Meaning that they let the constraints coming from their children/parents
-    # pass through them. So, for instance, a children of a task with an
-    # undefined or fuzzy task would be constrained by this latter task's
-    # ancestors. Equally, the an ancestor from the same undefined/fuzzy task
-    # would be constrained by the children due dates.
+    # dates are not subject to constraints. Furthermore, they are
+    # "transparent". Meaning that they let the constraints coming from their
+    # children/parents pass through them. So, for instance, a children of
+    # a task with an undefined or fuzzy task would be constrained by this
+    # latter task's ancestors. Equally, the an ancestor from the same
+    # undefined/fuzzy task would be constrained by the children due dates.
     #
     # Updating a task due date
     #
     # Whenever a task due date is changed, all ancestor/chldren of this task
     # *must* be updated according to the constraining rules. As said above,
     # constraints must go through tasks with undefined/fuzzy due dates too!
-    # 
-    # Undefined/fuzzy task dates are NEVER to be updated. They are not sensitive
-    # to constraint. If you want to now what constraint there is on this task's
-    # due date though, you can obtain it by using the get_due_date_constraint
-    # method.
-
+    #
+    # Undefined/fuzzy task dates are NEVER to be updated. They are not
+    # sensitive to constraint. If you want to now what constraint there is
+    # on this task's due date though, you can obtain it by using
+    # get_due_date_constraint method.
     def set_due_date(self, new_duedate):
         """Defines the task's due date."""
 
@@ -301,38 +302,33 @@ class Task(TreeNode):
             parent_list = []
             for par_id in task.parents:
                 par = self.req.get_task(par_id)
-                if par.get_due_date() == Date.no_date() or \
-                  ( par.get_due_date() != Date.no_date() and \
-                    par.get_due_date().is_fuzzy() ):
+                if par.get_due_date().is_fuzzy():
                     parent_list += __get_defined_parent_list(par)
                 else:
                     parent_list.append(par)
             return parent_list
 
         def __get_defined_child_list(task):
-            """Recursively fetch a list of children that have a defined due date
-               which is not fuzzy"""
+            """Recursively fetch a list of children that have a defined
+               due date which is not fuzzy"""
             child_list = []
             for child_id in task.children:
                 child = self.req.get_task(child_id)
-                if child.get_due_date() == Date.no_date() or \
-                   ( child.get_due_date() != Date.no_date() and \
-                     child.get_due_date().is_fuzzy() ):
+                if child.get_due_date().is_fuzzy():
                     child_list += __get_defined_child_list(child)
                 else:
                     child_list.append(child)
             return child_list
 
-        old_due_date    = self.due_date
-        new_duedate_obj = Date(new_duedate) # caching the conversion
-        self.due_date   = new_duedate_obj
+        old_due_date = self.due_date
+        new_duedate_obj = Date(new_duedate)  # caching the conversion
+        self.due_date = new_duedate_obj
         # If the new date is fuzzy or undefined, we don't update related tasks
-        if not new_duedate_obj.is_fuzzy() and new_duedate_obj != Date.no_date():
-            # if the task's start date happens later than the 
+        if not new_duedate_obj.is_fuzzy():
+            # if the task's start date happens later than the
             # new due date, we update it (except for fuzzy dates)
-            if self.get_start_date() != Date.no_date() and \
-               not self.get_start_date().is_fuzzy()    and \
-               self.get_start_date() > new_duedate_obj:
+            if not self.get_start_date().is_fuzzy() and \
+                    self.get_start_date() > new_duedate_obj:
                 self.set_start_date(new_duedate)
             # if some ancestors' due dates happen before the task's new
             # due date, we update them (except for fuzzy dates)
@@ -351,9 +347,8 @@ class Task(TreeNode):
                 # the task's new due date, we update it
                 # (except for fuzzy start dates)
                 sub_startdate = sub.get_start_date()
-                if sub_startdate != Date.no_date() and \
-                   not sub_startdate.is_fuzzy() and \
-                   sub_startdate > new_duedate_obj:
+                if not sub_startdate.is_fuzzy() and \
+                        sub_startdate > new_duedate_obj:
                     sub.set_start_date(new_duedate)
         # If the date changed, we notify the change for the children since the
         # constraints might have changed
@@ -364,33 +359,37 @@ class Task(TreeNode):
         """ Returns the due date, which always respects all constraints """
         return self.due_date
 
+    def get_urgent_date(self):
+        """Returns the most urgent due date among the task and it's subtasks"""
+        urg_date = self.due_date
+        for sub in self.get_subtasks():
+            sub_urg_date = sub.get_urgent_date()
+            if urg_date >= sub_urg_date:
+                urg_date = sub_urg_date
+        return urg_date
+
     def get_due_date_constraint(self):
         """ Returns the most urgent due date constraint, following
             parents' due dates. Return Date.no_date() if no constraint
             is applied. """
         # Check out for constraints depending on date definition/fuzziness.
         strongest_const_date = self.due_date
-        if strongest_const_date == Date.no_date() or \
-           ( strongest_const_date != Date.no_date() and \
-             strongest_const_date.is_fuzzy() ):
+        if strongest_const_date.is_fuzzy():
             for par_id in self.parents:
                 par = self.req.get_task(par_id)
                 par_duedate = par.get_due_date()
                 # if parent date is undefined or fuzzy, look further up
-                if par_duedate == Date.no_date() or \
-                   par_duedate.is_fuzzy():
+                if par_duedate.is_fuzzy():
                     par_duedate = par.get_due_date_constraint()
                 # if par_duedate is still undefined/fuzzy, all parents' due
                 # dates are undefined or fuzzy: strongest_const_date is then
                 # the best choice so far, we don't update it.
-                if par_duedate == Date.no_date() or \
-                   par_duedate.is_fuzzy():
+                if par_duedate.is_fuzzy():
                     continue
-                # par_duedate is not undefined/fuzzy. If strongest_const_date is
-                # still undefined or fuzzy, parent_duedate is the best choice.
-                if strongest_const_date == Date.no_date() or \
-                   ( strongest_const_date != Date.no_date() and \
-                     strongest_const_date.is_fuzzy() ):
+                # par_duedate is not undefined/fuzzy. If strongest_const_date
+                # is still undefined or fuzzy, parent_duedate is the best
+                # choice.
+                if strongest_const_date.is_fuzzy():
                     strongest_const_date = par_duedate
                     continue
                 # strongest_const_date and par_date are defined and not fuzzy:
@@ -403,22 +402,19 @@ class Task(TreeNode):
     #
     # Start date is the date at which the user has decided to work or consider
     # working on this task.
-    # 
+    #
     # The only constraint applied to start dates is that start dates cannot
     # happen later than the task due date.
-    # 
+    #
     # The task due date (and any constrained relatives) is updated if a new
     # task start date is chosen that does not respect this rule.
     #
     # Undefined/fizzy start dates don't constraint the task due date.
-
     def set_start_date(self, fulldate):
         self.start_date = Date(fulldate)
-        if Date(fulldate) != Date.no_date() and \
-           not Date(fulldate).is_fuzzy() and \
-           self.due_date != Date.no_date() and \
-           not self.due_date.is_fuzzy() and \
-           Date(fulldate) > self.due_date:
+        if not Date(fulldate).is_fuzzy() and \
+            not self.due_date.is_fuzzy() and \
+                Date(fulldate) > self.due_date:
             self.set_due_date(fulldate)
         self.sync()
 
@@ -430,7 +426,6 @@ class Task(TreeNode):
     # Closed date is the date at which the task has been closed (done or
     # dismissed). Closed date is not constrained and doesn't constrain other
     # dates.
-
     def set_closed_date(self, fulldate):
         self.closed_date = Date(fulldate)
         self.sync()
@@ -456,7 +451,7 @@ class Task(TreeNode):
             return ""
 
     def get_excerpt(self, lines=0, char=0, strip_tags=False,
-            strip_subtasks=True):
+                    strip_subtasks=True):
         """
         get_excerpt return the beginning of the content of the task.
         If "lines" is provided and different than 0, it return the number X
@@ -469,7 +464,7 @@ class Task(TreeNode):
         Warning: all markup informations are stripped down. Empty lines are
         also removed
         """
-        #defensive programmation to avoid returning None
+        # defensive programmation to avoid returning None
         if self.content:
             txt = self.content
             if strip_tags:
@@ -478,7 +473,7 @@ class Task(TreeNode):
             element = xml.dom.minidom.parseString(txt)
             txt = self.__strip_content(element, strip_subtasks=strip_subtasks)
             txt = txt.strip()
-            #We keep the desired number of lines
+            # We keep the desired number of lines
             if lines > 0:
                 liste = txt.splitlines()
                 for i in liste:
@@ -486,7 +481,7 @@ class Task(TreeNode):
                         liste.remove(i)
                 to_keep = liste[:lines]
                 txt = '\n'.join(to_keep)
-            #We keep the desired number of char
+            # We keep the desired number of char
             if char > 0:
                 txt = txt[:char]
             return txt
@@ -510,7 +505,7 @@ class Task(TreeNode):
     def set_text(self, texte):
         self.can_be_deleted = False
         if texte != "<content/>":
-            #defensive programmation to filter bad formatted tasks
+            # defensive programmation to filter bad formatted tasks
             if not texte.startswith("<content>"):
                 texte = cgi.escape(texte, quote=True)
                 texte = "<content>%s" % texte
@@ -527,7 +522,7 @@ class Task(TreeNode):
         a subtask
         """
         subt = self.req.new_task(newtask=True)
-        #we use the inherited childrens
+        # we use the inherited childrens
         self.add_child(subt.get_id())
         return subt
 
@@ -538,9 +533,9 @@ class Task(TreeNode):
         """
         Log.debug("adding child %s to task %s" % (tid, self.get_id()))
         self.can_be_deleted = False
-        #the core of the method is in the TreeNode object
+        # the core of the method is in the TreeNode object
         TreeNode.add_child(self, tid)
-        #now we set inherited attributes only if it's a new task
+        # now we set inherited attributes only if it's a new task
         child = self.req.get_task(tid)
         if self.is_loaded() and child and child.can_be_deleted:
             child.set_start_date(self.get_start_date())
@@ -564,14 +559,14 @@ class Task(TreeNode):
         else:
             return False
 
-    #FIXME: remove this function and use liblarch instead.
+    # FIXME: remove this function and use liblarch instead.
     def get_subtasks(self):
         tree = self.get_tree()
         return [tree.get_node(node_id) for node_id in self.get_children()]
 
-    #FIXME : why is this function used ? It's higly specific. Remove it?
+    # FIXME : why is this function used ? It's higly specific. Remove it?
     #        (Lionel)
-    #Agreed. it's only used by the "add tag to all subtasks" widget.
+    # Agreed. it's only used by the "add tag to all subtasks" widget.
     def get_self_and_all_subtasks(self, active_only=False, tasks=[]):
         print "DEPRECATED FUNCTION: get_self_and_all_subtasks"
         tasks.append(self)
@@ -583,7 +578,7 @@ class Task(TreeNode):
         return tasks
 
     def get_subtask(self, tid):
-        #FIXME : remove this function. This is not useful
+        # FIXME : remove this function. This is not useful
         print "DEPRECATED: get_subtask"
         """Return the task corresponding to a given ID.
 
@@ -597,11 +592,9 @@ class Task(TreeNode):
         if parent_id is not None:
             par = self.req.get_task(parent_id)
             par_duedate = par.get_due_date_constraint()
-            if par_duedate != Date.no_date() and \
-               not par_duedate.is_fuzzy()    and \
-               self.due_date != Date.no_date() and \
-               not self.due_date.is_fuzzy()  and \
-               par_duedate < self.due_date:
+            if not par_duedate.is_fuzzy() and \
+                not self.due_date.is_fuzzy() and \
+                    par_duedate < self.due_date:
                 self.set_due_date(par_duedate)
         self.recursive_sync()
 
@@ -626,7 +619,7 @@ class Task(TreeNode):
     def sync(self):
         self._modified_update()
         if self.is_loaded():
-            #This is a liblarch call to the TreeNode ancestor
+            # This is a liblarch call to the TreeNode ancestor
             self.modified()
             return True
         else:
@@ -641,10 +634,10 @@ class Task(TreeNode):
 ### TAG FUNCTIONS ############################################################
 #
     def get_tags_name(self):
-        #Return a copy of the list of tags. Not the original object.
+        # Return a copy of the list of tags. Not the original object.
         return list(self.tags)
 
-    #return a copy of the list of tag objects
+    # return a copy of the list of tag objects
     def get_tags(self):
         l = []
         for tname in self.tags:
@@ -670,7 +663,7 @@ class Task(TreeNode):
         Adds a tag. Does not add '@tag' to the contents. See add_tag
         """
         t = tagname.encode("UTF-8")
-        #Do not add the same tag twice
+        # Do not add the same tag twice
         if not t in self.tags:
             self.tags.append(t)
             if self.is_loaded():
@@ -689,7 +682,7 @@ class Task(TreeNode):
         if self.tag_added(tagname):
             c = self.content
 
-            #strip <content>...</content> tags
+            # strip <content>...</content> tags
             if c.startswith('<content>'):
                 c = c[len('<content>'):]
             if c.endswith('</content>'):
@@ -707,12 +700,12 @@ class Task(TreeNode):
 
             self.content = "<content><tag>%s</tag>%s%s</content>" % (
                 tagname, sep, c)
-            #we modify the task internal state, thus we have to call for a sync
+            # we modify the task internal state, thus we have to call for a
+            # sync
             self.sync()
 
-    #remove by tagname
+    # remove by tagname
     def remove_tag(self, tagname):
-#        print "remove tag %s" %tagname
         modified = False
         if tagname in self.tags:
             self.tags.remove(tagname)
@@ -728,7 +721,6 @@ class Task(TreeNode):
             tag.update_task(self.get_id())
             if tag:
                 tag.modified()
-#            print "removing now %s and tag is %s - %s" %(tagname,tag, tag.get_active_tasks_count())
 
     def set_only_these_tags(self, tags_list):
         '''
@@ -745,22 +737,22 @@ class Task(TreeNode):
 
     def _strip_tag(self, text, tagname, newtag=''):
         return (text
-                    .replace('<tag>%s</tag>\n\n' % (tagname), newtag) #trail \n
-                    #trail comma
-                    .replace('<tag>%s</tag>, ' % (tagname), newtag)
-                    .replace('<tag>%s</tag>,' % (tagname), newtag)
-                    .replace('<tag>%s</tag>' % (tagname), newtag)
-                    #in case XML is missing (bug #504899)
-                    .replace('%s\n\n' % (tagname), newtag)
-                    .replace('%s, ' % (tagname), newtag)
-                    .replace('%s,' % (tagname), newtag)
-                    #don't forget a space a the end
-                    .replace('%s ' % (tagname), newtag))
+                .replace('<tag>%s</tag>\n\n' % (tagname), newtag)  # trail \n
+                # trail comma
+                .replace('<tag>%s</tag>, ' % (tagname), newtag)
+                .replace('<tag>%s</tag>,' % (tagname), newtag)
+                .replace('<tag>%s</tag>' % (tagname), newtag)
+                # in case XML is missing (bug #504899)
+                .replace('%s\n\n' % (tagname), newtag)
+                .replace('%s, ' % (tagname), newtag)
+                .replace('%s,' % (tagname), newtag)
+                # don't forget a space a the end
+                .replace('%s ' % (tagname), newtag))
 
-    #tag_list is a list of tags names
-    #return true if at least one of the list is in the task
+    # tag_list is a list of tags names
+    # return true if at least one of the list is in the task
     def has_tags(self, tag_list=None, notag_only=False):
-        #recursive function to explore the tags and its children
+        # recursive function to explore the tags and its children
         def children_tag(tagname):
             toreturn = False
             if tagname in self.tags:
@@ -772,20 +764,20 @@ class Task(TreeNode):
                         toreturn = children_tag(tagc_name)
             return toreturn
 
-        #We want to see if the task has no tags
+        # We want to see if the task has no tags
         toreturn = False
         if notag_only:
             toreturn = self.tags == []
-        #Here, the user ask for the "empty" tag
-        #And virtually every task has it.
-        elif tag_list == [] or tag_list == None:
+        # Here, the user ask for the "empty" tag
+        # And virtually every task has it.
+        elif tag_list == [] or tag_list is None:
             toreturn = True
         elif tag_list:
             for tagname in tag_list:
                 if not toreturn:
                     toreturn = children_tag(tagname)
         else:
-            #Well, if we don't filter on tags or notag, it's true, of course
+            # Well, if we don't filter on tags or notag, it's true, of course
             toreturn = True
         return toreturn
 
