@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -19,7 +19,7 @@
 
 #=== IMPORT ===================================================================
 
-#system imports
+# system imports
 import pygtk
 pygtk.require('2.0')
 import gobject
@@ -30,16 +30,17 @@ from GTG.tools.logger import Log
 
 #=== MAIN CLASS ===============================================================
 
+
 class CellRendererTags(gtk.GenericCellRenderer):
     __gproperties__ = {
-        'tag_list': (gobject.TYPE_PYOBJECT,\
-            "Tag list", "A list of tags", gobject.PARAM_READWRITE),
-        'tag': (gobject.TYPE_PYOBJECT, "Tag",\
-             "Tag", gobject.PARAM_READWRITE),
+        'tag_list': (gobject.TYPE_PYOBJECT,
+                     "Tag list", "A list of tags", gobject.PARAM_READWRITE),
+        'tag': (gobject.TYPE_PYOBJECT, "Tag",
+                "Tag", gobject.PARAM_READWRITE),
     }
 
     # Private methods
-    def __roundedrec(self, context, x, y, w, h, r = 10):
+    def __roundedrec(self, context, x, y, w, h, r=10):
         "Draw a rounded rectangle"
         #   A****BQ
         #  H      C
@@ -47,29 +48,31 @@ class CellRendererTags(gtk.GenericCellRenderer):
         #  G      D
         #   F****E
 
-        context.move_to(x+r, y)                          # Move to A
-        context.line_to(x+w-r, y)                        # Straight line to B
+        context.move_to(x + r, y)                          # Move to A
+        context.line_to(
+            x + w - r, y)                        # Straight line to B
         # Curve to C, Control points are both at Q
-        context.curve_to(x+w, y, x+w, y, x+w, y+r)
-        context.line_to(x+w, y+h-r)                      # Move to D
-        context.curve_to(x+w, y+h, x+w, y+h, x+w-r, y+h) # Curve to E
-        context.line_to(x+r, y+h)                        # Line to F
-        context.curve_to(x, y+h, x, y+h, x, y+h-r)       # Curve to G
-        context.line_to(x, y+r)                          # Line to H
-        context.curve_to(x, y, x, y, x+r, y)             # Curve to A
+        context.curve_to(x + w, y, x + w, y, x + w, y + r)
+        context.line_to(x + w, y + h - r)                      # Move to D
+        context.curve_to(
+            x + w, y + h, x + w, y + h, x + w - r, y + h)  # Curve to E
+        context.line_to(x + r, y + h)                        # Line to F
+        context.curve_to(x, y + h, x, y + h, x, y + h - r)       # Curve to G
+        context.line_to(x, y + r)                          # Line to H
+        context.curve_to(x, y, x, y, x + r, y)             # Curve to A
         return
 
     def __count_viewable_tags(self):
 
         count = 0
 
-        if self.tag_list != None:
+        if self.tag_list is not None:
             for my_tag in self.tag_list:
                 my_tag_color = my_tag.get_attribute("color")
-                my_tag_icon  = my_tag.get_attribute("icon")
+                my_tag_icon = my_tag.get_attribute("icon")
                 if my_tag_color or my_tag_icon:
                     count = count + 1
-        elif self.tag != None:
+        elif self.tag is not None:
             count = 1
         else:
             count = 0
@@ -77,13 +80,13 @@ class CellRendererTags(gtk.GenericCellRenderer):
         return count
 
     # Class methods
-    def __init__(self): #pylint: disable-msg=W0231
+    def __init__(self):
         self.__gobject_init__()
         self.tag_list = None
-        self.tag      = None
-        self.xpad     = 1
-        self.ypad     = 1
-        self.PADDING  = 1
+        self.tag = None
+        self.xpad = 1
+        self.ypad = 1
+        self.PADDING = 1
 
     def do_set_property(self, pspec, value):
         if pspec.name == "tag-list":
@@ -97,45 +100,46 @@ class CellRendererTags(gtk.GenericCellRenderer):
         else:
             return getattr(self, pspec.name)
 
-    def on_render(\
-        self, window, widget, background_area, cell_area, expose_area, flags):
+    def on_render(self, window, widget, background_area, cell_area,
+                  expose_area, flags):
 
         vw_tags = self.__count_viewable_tags()
-        count   = 0
+        count = 0
 
         # Select source
-        if self.tag_list != None:
+        if self.tag_list is not None:
             tags = self.tag_list
-        elif self.tag != None:
+        elif self.tag is not None:
             tags = [self.tag]
         else:
             return
 
         # Drawing context
-        cr         = window.cairo_create()
+        cr = window.cairo_create()
         gdkcontext = gtk.gdk.CairoContext(cr)
         gdkcontext.set_antialias(cairo.ANTIALIAS_NONE)
 
         # Coordinates of the origin point
         x_align = self.get_property("xalign")
         y_align = self.get_property("yalign")
-        orig_x  = cell_area.x + int((cell_area.width  - 16*vw_tags -\
-            self.PADDING*2*(vw_tags-1)) * x_align)
-        orig_y  = cell_area.y + int((cell_area.height - 16) * y_align)
+        padding = self.PADDING
+        orig_x = cell_area.x + int((cell_area.width - 16 * vw_tags -
+                                    padding * 2 * (vw_tags - 1)) * x_align)
+        orig_y = cell_area.y + int((cell_area.height - 16) * y_align)
 
         # We draw the icons & squares
         for my_tag in tags:
 
-            my_tag_icon  = my_tag.get_attribute("icon")
+            my_tag_icon = my_tag.get_attribute("icon")
             my_tag_color = my_tag.get_attribute("color")
 
-            rect_x  = orig_x + self.PADDING*2*count + 16*count
-            rect_y  = orig_y
+            rect_x = orig_x + self.PADDING * 2 * count + 16 * count
+            rect_y = orig_y
 
             if my_tag_icon:
                 try:
                     pixbuf = gtk.icon_theme_get_default().load_icon(
-                                    my_tag_icon, 16, 0)
+                        my_tag_icon, 16, 0)
                     gdkcontext.set_source_pixbuf(pixbuf, rect_x, rect_y)
                     gdkcontext.paint()
                     count = count + 1
@@ -160,13 +164,12 @@ class CellRendererTags(gtk.GenericCellRenderer):
                 self.__roundedrec(gdkcontext, rect_x, rect_y, 16, 16, 8)
                 gdkcontext.stroke()
 
-        if self.tag and my_tag: #pylint: disable-msg=W0631
+        if self.tag and my_tag:
 
-            my_tag_icon  = my_tag.get_attribute("icon")
+            my_tag_icon = my_tag.get_attribute("icon")
             my_tag_color = my_tag.get_attribute("color")
 
-            if   not my_tag_icon and not my_tag_color:
-
+            if not my_tag_icon and not my_tag_color:
                 # Draw rounded rectangle
                 gdkcontext.set_source_rgba(0.95, 0.95, 0.95, 1)
                 self.__roundedrec(gdkcontext, rect_x, rect_y, 16, 16, 8)
@@ -178,14 +181,15 @@ class CellRendererTags(gtk.GenericCellRenderer):
                 self.__roundedrec(gdkcontext, rect_x, rect_y, 16, 16, 8)
                 gdkcontext.stroke()
 
-    def on_get_size(self, widget, cell_area=None): #pylint: disable-msg=W0613
+    def on_get_size(self, widget, cell_area=None):
 
         count = self.__count_viewable_tags()
 
         if count != 0:
-            return (self.xpad, self.ypad, self.xpad*2 + 16*count +\
-                 2*count*self.PADDING, 16 + 2*self.ypad)
+            return (self.xpad, self.ypad,
+                    self.xpad * 2 + 16 * count + 2 * count * self.PADDING,
+                    16 + 2 * self.ypad)
         else:
-            return (self.xpad, self.ypad, self.xpad*2, self.ypad*2)
+            return (self.xpad, self.ypad, self.xpad * 2, self.ypad * 2)
 
 gobject.type_register(CellRendererTags)
