@@ -17,6 +17,6 @@
 from GTG.plugins.geolocalized_tasks.geolocalized_tasks import geolocalizedTasks
 
 
-#suppress pyflakes warning (given by make lint)
-if False == True:
+# suppress pyflakes warning (given by make lint)
+if False is True:
     geolocalizedTasks()
