@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Getting Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -17,6 +17,7 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 
+
 class BiDict(object):
     '''
     Bidirectional dictionary: the pairs stored can be accessed using either the
@@ -104,6 +105,6 @@ class BiDict(object):
 
         @returns: string
         '''
-        return reduce(lambda text, keys: \
+        return reduce(lambda text, keys:
                       str(text) + str(keys),
                       self._first_to_second.iteritems())
